==> edubotics_core-0.1.2.tar.gz: edubotics_core-0.1.2/README.md <==

<p align="center">
  <a href="http://docs.edubotics.ai/">
    <img src="https://github.com/edubotics-ai/.github/blob/main/assets/images/edubot-mascot.png?raw=true" alt="edubotics-ai" width="10%" height="10%">
  </a>
</p>
<p align="center">
    <em>Edubotics AI - Empower Education with AI: Create Intelligent Chatbots Quickly and Efficiently</em>
</p>
<p align="center">
    <a href="https://github.com/edubotics-ai/edubot-core">
        <img src="https://img.shields.io/pypi/v/edubotics-core.svg" alt="PyPI">
    </a>
    <a href="https://github.com/edubotics-ai/edubot-core">
        <img src="https://img.shields.io/github/stars/edubotics-ai/edubot-core.svg" alt="GitHub stars">
    </a>
    <a href="https://github.com/edubotics-ai/edubot-core">
        <img src="https://img.shields.io/github/license/edubotics-ai/edubot-core.svg" alt="License">
    </a>
    <a href="https://pypi.org/project/edubotics-core">
        <img src="https://img.shields.io/pypi/dm/edubotics-core.svg" alt="PyPI Downloads">
    </a>
    <a href="https://github.com/edubotics-ai/edubot-core/graphs/contributors">
        <img src="https://img.shields.io/github/contributors/edubotics-ai/edubot-core.svg" alt="GitHub Contributors">
    </a>
</p>

## Welcome to edubotics-core by Edubotics AI! 👋

**edubotics-core** is an open-source Python library that allows developers to build LLM-based chatbots efficiently. It provides a comprehensive set of core modules for vector storage, retrieval, processing, with more to come.

## 🛠 Installation

You can install edubotics-core using pip:

```bash
pip install edubotics-core
```

Full documentation can be found [here](https://edubotics-ai.github.io/edubot-core/).

## ✨ Key Features
- Modular and Extensible: Easily create, modify, and extend to the core modules.


## 📚 Applications

To see the full extent of what edubotics-core can do, check out the app templates we have built:

- [Edubotics AI Tutor](https://github.com/edubotics-ai/edubot-app): A Digital AI Teaching Assistant setup for the [DS598](https://dl4ds.github.io/sp2024/) course at Boston University.

## 💁 Contributing

We welcome contributions to edubotics-core! If you're interested in contributing, please check out our [contributing guidelines](CONTRIBUTING.md) for more details.

## 📜 License

edubotics-core is licensed under the MIT License. See the [LICENSE](LICENSE) file for more details.

==> edubotics_core-0.1.3.tar.gz: edubotics_core-0.1.3/README.md <==

<p align="center">
  <a href="http://docs.edubotics.ai/">
    <img src="https://github.com/edubotics-ai/.github/blob/main/assets/images/edubot-mascot.png?raw=true" alt="edubotics-ai" width="10%" height="10%">
  </a>
</p>
<p align="center">
    <em>Edubotics AI - Empower Education with AI: Create Intelligent Chatbots Quickly and Efficiently</em>
</p>
<p align="center">
    <a href="https://github.com/edubotics-ai/edubot-core">
        <img src="https://img.shields.io/pypi/v/edubotics-core.svg" alt="PyPI">
    </a>
    <a href="https://github.com/edubotics-ai/edubot-core">
        <img src="https://img.shields.io/github/stars/edubotics-ai/edubot-core.svg" alt="GitHub stars">
    </a>
    <a href="https://github.com/edubotics-ai/edubot-core">
        <img src="https://img.shields.io/github/license/edubotics-ai/edubot-core.svg" alt="License">
    </a>
    <a href="https://pypi.org/project/edubotics-core">
        <img src="https://img.shields.io/pypi/dm/edubotics-core.svg" alt="PyPI Downloads">
    </a>
    <a href="https://github.com/edubotics-ai/edubot-core/graphs/contributors">
        <img src="https://img.shields.io/github/contributors/edubotics-ai/edubot-core.svg" alt="GitHub Contributors">
    </a>
</p>

## Welcome to edubotics-core by Edubotics AI! 👋

**edubotics-core** is an open-source Python library that allows developers to build LLM-based chatbots efficiently. It provides a comprehensive set of core modules for vector storage, retrieval, processing, with more to come.

## 🛠 Installation

You can install edubotics-core using pip:

```bash
pip install edubotics-core
```

Full documentation can be found [here](http://docs.edubotics.ai/).

## ✨ Key Features
- Modular and Extensible: Easily create, modify, and extend to the core modules.


## 📚 Applications

To see the full extent of what edubotics-core can do, check out the app templates we have built:

- [Edubotics AI Tutor](https://github.com/edubotics-ai/edubot-app): A Digital AI Teaching Assistant setup for the [DS598](https://dl4ds.github.io/sp2024/) course at Boston University.

## 💁 Contributing

We welcome contributions to edubotics-core! If you're interested in contributing, please check out our [contributing guidelines](CONTRIBUTING.md) for more details.

## 📜 License

edubotics-core is licensed under the MIT License. See the [LICENSE](LICENSE) file for more details.
